@@ -25,10 +25,12 @@ class ShaderProgram:
     def drawables(self) -> list:
         return self.opaques + self.transparents
 
-    def setup(self) -> None:
-        if self.shader_program:
-            return
+    def get_base_name(self) -> str:
+        return self.base_name
 
+    def initialize(self) -> None:
+        # FIXME In the future, check how often we need 'self.viewer'
+        #  We might be able to receive it as parameter and not use it ever again
         self.shader_program = QOpenGLShaderProgram(self.viewer.context())
         self.setup_shaders()
 
@@ -73,9 +75,6 @@ class ShaderProgram:
     def bind(self) -> None:
         self.shader_program.bind()
 
-    def recreate(self) -> None:
-        pass
-
     def inner_draw(self, drawables: list) -> None:
         for drawable in drawables:
             drawable.draw()
