@@ -83,12 +83,16 @@ class MainWindow(QMainWindow):
         self.connect_actions()
 
         # Set auto-fit as True when starting the app
-        if not actions.action_autofit_to_screen.isChecked():
-            actions.action_autofit_to_screen.trigger()
+        if not actions.action_autofit.isChecked():
+            actions.action_autofit.trigger()
+
+        # Set auto-rotate as True when starting the app
+        if not actions.action_autorotate.isChecked():
+            actions.action_autorotate.trigger()
 
         # Set animated as True when starting the app
-        if not actions.action_animated_viewer.isChecked():
-            actions.action_animated_viewer.trigger()
+        if not actions.action_animate.isChecked():
+            actions.action_animate.trigger()
 
         # Set camera widget as hidden
         self.dockWidget_camera.hide()
@@ -119,8 +123,9 @@ class MainWindow(QMainWindow):
         self.menu_View.addAction(actions.action_east_view)
         self.menu_View.addAction(actions.action_fit_to_screen)
         self.menu_View.addSeparator()
-        self.menu_View.addAction(actions.action_autofit_to_screen)
-        self.menu_View.addAction(actions.action_animated_viewer)
+        self.menu_View.addAction(actions.action_autofit)
+        self.menu_View.addAction(actions.action_animate)
+        self.menu_View.addAction(actions.action_autorotate)
         self.menu_View.addAction(actions.action_turbo_rendering)
         self.menu_View.addSeparator()
         self.menu_View.addAction(actions.action_perspective_projection)
@@ -128,7 +133,8 @@ class MainWindow(QMainWindow):
         self.menu_View.addSeparator()
         self.menu_View.addAction(actions.action_take_screenshot)
 
-        self.menu_Tools.addAction(actions.action_slice_mode)
+        self.menu_Tools.addAction(actions.action_slice_meshes)
+        self.menu_Tools.addAction(actions.action_slice_blocks)
         self.menu_Tools.addAction(actions.action_detection_mode)
         self.menu_Tools.addAction(actions.action_measurement_mode)
         self.menu_Tools.addSeparator()
@@ -167,8 +173,9 @@ class MainWindow(QMainWindow):
         actions.action_take_screenshot.triggered.connect(self.slot_screenshot)
 
         # Tools
+        actions.action_slice_meshes.triggered.connect(self.slot_slice_meshes)
+        actions.action_slice_blocks.triggered.connect(self.slot_slice_blocks)
         actions.action_detection_mode.triggered.connect(self.slot_detection_mode)
-        actions.action_slice_mode.triggered.connect(self.slot_slice_mode)
         actions.action_measurement_mode.triggered.connect(self.slot_measurement_mode)
         actions.action_normal_mode.triggered.connect(self.slot_normal_mode)
 
@@ -181,7 +188,6 @@ class MainWindow(QMainWindow):
         self.viewer.signal_mode_updated.connect(self.slot_mode_updated)
         self.viewer.signal_mesh_clicked.connect(self.slot_mesh_clicked)
         self.viewer.signal_mesh_distances.connect(self.slot_mesh_distances)
-        self.viewer.signal_slice_description.connect(self.slot_slice_description)
 
         self.viewer.signal_load_success.connect(self.slot_element_load_success)
         self.viewer.signal_load_failure.connect(self.slot_element_load_failure)
@@ -216,7 +222,6 @@ class MainWindow(QMainWindow):
     Status bar updates
     """
     def slot_element_load_success(self, _id: int) -> None:
-        self.viewer.update_turbo()
         self.statusBar.showMessage(f'Load successful (id: {_id}).')
 
     def slot_element_load_failure(self) -> None:
@@ -241,24 +246,45 @@ class MainWindow(QMainWindow):
     """
     Slots for cross-sections
     """
-    def slot_slice_description(self, description: dict) -> None:
+    def handle_slices(self, description: dict, executer: callable) -> None:
+        # Retrieve description vectors
         origin = description.get('origin')
         normal = description.get('normal')
         up = description.get('up')
 
-        # Slice elements
-        mesh_slices = self.viewer.slice_meshes(origin, normal)
-        block_slices = self.viewer.slice_blocks(origin, normal)
-
-        # Add to elements
-        self.add_mesh_slices(mesh_slices)
-        self.add_block_slices(block_slices)
+        # Execute the callable over the elements
+        executer(origin, normal)
 
         # Auto-rotate camera to meet cross-section
-        self.viewer.set_camera_from_vectors(normal, up)
+        actions = self.toolbar.action_collection
+        if actions.action_autorotate.isChecked():
+            self.viewer.set_camera_from_vectors(normal, up)
 
-        # Auto-exit slice mode
+        # Auto-exit and disconnect
         self.viewer.set_normal_mode()
+        self.viewer.signal_slice_description.disconnect()
+
+    def slot_slice_meshes(self) -> None:
+        def executer(origin, normal) -> None:
+            slices = self.viewer.slice_meshes(origin, normal)
+            self.add_mesh_slices(slices)
+
+        def handler(description: dict) -> None:
+            self.handle_slices(description, executer)
+
+        self.viewer.set_slice_mode()
+        self.viewer.signal_slice_description.connect(handler)
+
+    def slot_slice_blocks(self) -> None:
+        def executer(origin, normal) -> None:
+            slices = self.viewer.slice_blocks(origin, normal)
+            self.add_block_slices(slices)
+
+        def handler(description: dict) -> None:
+            self.handle_slices(description, executer)
+
+        self.viewer.set_slice_mode()
+        self.viewer.signal_slice_description.connect(handler)
 
     def add_mesh_slices(self, slice_list: list) -> None:
         for sliced_meshes in slice_list:
@@ -426,7 +452,7 @@ class MainWindow(QMainWindow):
                                     method=self.viewer.export_tubes)
 
     """
-    Slots for modifying controller modes
+    Slots for modifying interaction modes
     """
     def slot_normal_mode(self) -> None:
         self.viewer.set_normal_mode()
@@ -434,9 +460,6 @@ class MainWindow(QMainWindow):
     def slot_detection_mode(self) -> None:
         self.viewer.set_detection_mode()
 
-    def slot_slice_mode(self) -> None:
-        self.viewer.set_slice_mode()
-
     def slot_measurement_mode(self) -> None:
         self.viewer.set_measurement_mode()
 
