@@ -37,6 +37,7 @@ from .drawables.tubegl import TubeGL
 from .drawablefactory import DrawableFactory
 from .fpscounter import FPSCounter
 
+from ..controller.mode import Mode
 from ..controller.detectionmode import DetectionMode
 from ..controller.normalmode import NormalMode
 from ..controller.slicemode import SliceMode
@@ -119,16 +120,15 @@ class IntegrableViewer(QOpenGLWidget):
 
         # Signals
         self.signal_file_modified.connect(self.recreate)
-        self.signal_file_modified.connect(self.update_autofit)
         self.signal_camera_rotated.connect(self.update)
         self.signal_camera_translated.connect(self.update)
         self.signal_center_translated.connect(self.update)
 
         # Controllers
-        self.add_controller(NormalMode, 'normal')
-        self.add_controller(DetectionMode, 'detection')
-        self.add_controller(SliceMode, 'slice')
-        self.add_controller(MeasurementMode, 'measurement')
+        self.add_controller(NormalMode(self))
+        self.add_controller(DetectionMode(self))
+        self.add_controller(SliceMode(self))
+        self.add_controller(MeasurementMode(self))
         self.set_normal_mode()
 
         # FPSCounter
@@ -149,6 +149,12 @@ class IntegrableViewer(QOpenGLWidget):
     def axis(self) -> GLDrawable:
         return self.axis_collection.get_last()
 
+    # DEPRECATED
+    @property
+    def bg(self) -> GLDrawable:
+        self._deprecated_message('bg', 'background')
+        return self.background
+
     @property
     def background(self) -> GLDrawable:
         return self.background_collection.get_last()
@@ -217,14 +223,14 @@ class IntegrableViewer(QOpenGLWidget):
 
         def setter(value):
             self.camera_position = value
-        self.animate(origin, target, method=setter) if self.get_animated_status() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
 
     def set_rotation_center(self, target) -> None:
         origin = self.get_rotation_center()
 
         def setter(value):
             self.rotation_center = value
-        self.animate(origin, target, method=setter) if self.get_animated_status() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
 
     def set_rotation_angle(self, target) -> None:
         # Fix any difference > 180° so the camera doesn't over-rotate
@@ -234,42 +240,29 @@ class IntegrableViewer(QOpenGLWidget):
 
         def setter(value):
             self.rotation_angle = value
-        self.animate(origin, target, method=setter) if self.get_animated_status() else setter(target)
+        self.animate(origin, target, method=setter) if self.is_animated() else setter(target)
 
     """
-    Turbo/Auto-fit/Animation
+    Animation / Turbo
     """
-    def get_turbo_status(self) -> bool:
-        return self._turbo
+    def set_turbo_rendering(self, status: bool) -> None:
+        self.blockSignals(True)
 
-    def get_autofit_status(self) -> bool:
-        return self._autofit
+        for d in self.get_all_drawables():
+            d.is_boostable = status
 
-    def get_animated_status(self) -> bool:
+        self.blockSignals(False)
+        self.recreate()
+
+    def is_animated(self) -> bool:
         return self._animated
 
-    def set_turbo_status(self, status: bool) -> None:
-        self._turbo = status
-        self.update_turbo()
-
-    def set_autofit_status(self, status: bool) -> None:
-        self._autofit = status
-        self.update_autofit()
-
-    def set_animated_status(self, status: bool) -> None:
+    def set_animated(self, status: bool) -> None:
         self._animated = status
 
-    def update_turbo(self) -> None:
-        for d in self.get_all_drawables():
-            d.is_boostable = self.get_turbo_status()
-
-    def update_autofit(self) -> None:
-        if self.get_autofit_status():
-            self.fit_to_screen()
-
-    def animate(self, start, end, method: callable, frames: int = 20) -> callable:
+    def animate(self, start, end, method: callable, steps: int = 20) -> callable:
         timer = QTimer(self)
-        linspace = iter(np.linspace(start, end, frames))
+        linspace = iter(np.linspace(start, end, steps))
 
         def animation_per_frame():
             try:
@@ -404,47 +397,47 @@ class IntegrableViewer(QOpenGLWidget):
     Load methods by path (DEPRECATED)
     """
     @staticmethod
-    def _deprecated_message(log: callable, old: str, new: str) -> None:
+    def _deprecated_message(old: str, new: str, log: callable = warnings.warn) -> None:
         log(f'{old} is deprecated. Use {new} instead.', DeprecationWarning, 2)
 
     def mesh_by_path(self, path: str, *args, **kwargs) -> MeshGL:
-        self._deprecated_message(warnings.warn, 'mesh_by_path()', 'load_mesh()')
+        self._deprecated_message('mesh_by_path()', 'load_mesh()')
         return self.load_mesh(path, *args, **kwargs)
 
     def blocks_by_path(self, path: str, *args, **kwargs) -> BlockGL:
-        self._deprecated_message(warnings.warn, 'blocks_by_path()', 'load_blocks()')
+        self._deprecated_message('blocks_by_path()', 'load_blocks()')
         return self.load_blocks(path, *args, **kwargs)
 
     def points_by_path(self, path: str, *args, **kwargs) -> PointGL:
-        self._deprecated_message(warnings.warn, 'points_by_path()', 'load_points()')
+        self._deprecated_message('points_by_path()', 'load_points()')
         return self.load_points(path, *args, **kwargs)
 
     def lines_by_path(self, path: str, *args, **kwargs) -> LineGL:
-        self._deprecated_message(warnings.warn, 'lines_by_path()', 'load_lines()')
+        self._deprecated_message('lines_by_path()', 'load_lines()')
         return self.load_lines(path, *args, **kwargs)
 
     def tubes_by_path(self, path: str, *args, **kwargs) -> TubeGL:
-        self._deprecated_message(warnings.warn, 'tubes_by_path()', 'load_tubes()')
+        self._deprecated_message('tubes_by_path()', 'load_tubes()')
         return self.load_tubes(path, *args, **kwargs)
 
     def meshes_by_folder_path(self, path: str, *args, **kwargs) -> list:
-        self._deprecated_message(warnings.warn, 'meshes_by_folder_path()', 'load_mesh_folder()')
+        self._deprecated_message('meshes_by_folder_path()', 'load_mesh_folder()')
         return self.load_mesh_folder(path, *args, **kwargs)
 
     def blocks_by_folder_path(self, path: str, *args, **kwargs) -> list:
-        self._deprecated_folder(warnings.warn, 'blocks_by_folder_path()', 'load_blocks_folder()')
+        self._deprecated_folder('blocks_by_folder_path()', 'load_blocks_folder()')
         return self.load_blocks_folder(path, *args, **kwargs)
 
     def points_by_folder_path(self, path: str, *args, **kwargs) -> list:
-        self._deprecated_folder(warnings.warn, 'points_by_folder_path()', 'load_points_folder()')
+        self._deprecated_folder('points_by_folder_path()', 'load_points_folder()')
         return self.load_points_folder(path, *args, **kwargs)
 
     def lines_by_folder_path(self, path: str, *args, **kwargs) -> list:
-        self._deprecated_folder(warnings.warn, 'lines_by_folder_path()', 'load_lines_folder()')
+        self._deprecated_folder('lines_by_folder_path()', 'load_lines_folder()')
         return self.load_lines_folder(path, *args, **kwargs)
 
     def tubes_by_folder_path(self, path: str, *args, **kwargs) -> list:
-        self._deprecated_folder(warnings.warn, 'tubes_by_folder_path()', 'load_tubes_folder()')
+        self._deprecated_folder('tubes_by_folder_path()', 'load_tubes_folder()')
         return self.load_tubes_folder(path, *args, **kwargs)
 
     """
@@ -583,6 +576,11 @@ class IntegrableViewer(QOpenGLWidget):
         glEnable(GL_DEPTH_TEST)
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA)
 
+        # Initialize collections
+        self.background_collection.initialize()
+        self.drawable_collection.initialize()
+        self.axis_collection.initialize()
+
     def paintGL(self) -> None:
         # Clear screen
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
@@ -608,11 +606,16 @@ class IntegrableViewer(QOpenGLWidget):
         # Project (Perspective/Orthographic)
         self.resizeGL(self.width(), self.height())
 
+        # Update matrices
+        self.drawable_collection.update_matrix('proj_matrix', self.proj)
+        self.drawable_collection.update_matrix('model_view_matrix', self.camera * self.world)
+        self.axis_collection.update_matrix('model_view_matrix', self.camera * self.world)
+
         # Draw every GLDrawable (meshes, blocks, points, etc)
         glEnable(GL_BLEND)
-        self.background_collection.draw(self.proj, self.camera, self.world)
-        self.drawable_collection.draw(self.proj, self.camera, self.world)
-        self.axis_collection.draw(self.proj, self.camera, self.world)
+        self.background_collection.draw()
+        self.drawable_collection.draw()
+        self.axis_collection.draw()
 
         # Tick FPS counter
         self.fps_counter.tick()
@@ -732,7 +735,7 @@ class IntegrableViewer(QOpenGLWidget):
         # Auto-moves the camera using the normal as direction
         self.set_rotation_angle(self.angles_from_vectors(normal, up))
 
-    def cross_section(self, origin_list: list, ray_list: list) -> None:
+    def generate_slice_description(self, origin_list: list, ray_list: list) -> None:
         # A plane is created from `origin` and `ray_list`.
         # In perspective projection, the origin is the same.
         origin = origin_list[0]
@@ -778,47 +781,47 @@ class IntegrableViewer(QOpenGLWidget):
     """
     Controller
     """
-    def add_controller(self, mode, mode_name: str) -> None:
-        self.controllers[mode_name] = mode
+    def add_controller(self, controller: Mode) -> None:
+        self.controllers[controller.name] = controller
 
     def set_controller(self, mode_name: str) -> None:
-        self.current_mode = self.controllers.get(mode_name)()
+        self.current_mode = self.controllers.get(mode_name)
         self.signal_mode_updated.emit(self.current_mode.name)
         self.update()
 
     def set_normal_mode(self) -> None:
-        self.set_controller('normal')
+        self.set_controller('Normal Mode')
 
     def set_detection_mode(self) -> None:
-        self.set_controller('detection')
+        self.set_controller('Detection Mode')
 
     def set_slice_mode(self) -> None:
-        self.set_controller('slice')
+        self.set_controller('Slice Mode')
 
     def set_measurement_mode(self) -> None:
-        self.set_controller('measurement')
+        self.set_controller('Measurement Mode')
 
     """
     Events (dependent on current controller)
     """
     def mouseMoveEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseMoveEvent(event, self)
+        self.current_mode.mouseMoveEvent(event)
         self.update()
 
     def mousePressEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mousePressEvent(event, self)
+        self.current_mode.mousePressEvent(event)
         self.update()
 
     def mouseDoubleClickEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseDoubleClickEvent(event, self)
+        self.current_mode.mouseDoubleClickEvent(event)
         self.update()
 
     def mouseReleaseEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.mouseReleaseEvent(event, self)
+        self.current_mode.mouseReleaseEvent(event)
         self.update()
 
     def wheelEvent(self, event, *args, **kwargs) -> None:
-        self.current_mode.wheelEvent(event, self)
+        self.current_mode.wheelEvent(event)
         self.update()
 
     def dragEnterEvent(self, event, *args, **kwargs) -> None:
